@@ -1,18 +1,15 @@
 package BeerDB;
-use base 'Maypole::Application';
+use base 'Apache::MVC';
 use Class::DBI::Loader::Relationship;
 
 # This is the sample application. Change this to the path to your
 # database. (or use mysql or something)
-BeerDB->setup("dbi:SQLite:t/beerdb.db");
-#BeerDB->setup("dbi:mysql:beerdb");
-
-# Give it a name.
-BeerDB->config->{application_name} = 'The Beer Database';
+#BeerDB->set_database("dbi:SQLite:t/beerdb.db");
+BeerDB->setup("dbi:mysql:beerdb");
 
 # Change this to the root of the web space.
-BeerDB->config->{uri_base} = "http://localhost/beerdb/";
-#BeerDB->config->{uri_base} = "http://neo.trinity-house.org.uk/beerdb/";
+#BeerDB->config->{uri_base} = "http://localhost/beerdb/";
+BeerDB->config->{uri_base} = "http://neo.trinity-house.org.uk/beerdb/";
 
 BeerDB->config->{rows_per_page} = 10;
 
@@ -21,7 +18,7 @@ BeerDB->config->{display_tables} = [qw[beer brewery pub style]];
 BeerDB::Brewery->untaint_columns( printable => [qw/name notes url/] );
 BeerDB::Style->untaint_columns( printable => [qw/name notes/] );
 BeerDB::Beer->untaint_columns(
-    printable => [qw/abv name price notes url/],
+    printable => [qw/abv name price notes/],
     integer => [qw/style brewery score/],
     date =>[ qw/date/],
 );
